# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%else
%define build_docs 1
%endif

%bcond_without examples

# Versioning

%define qtmajor 6
%define qtminor 8
%define qtsubminor 3
%define qtversion  %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 2

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir       qtpositioning-everywhere-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libqtpositioning   %mklibname qt%{qtmajor}positioning %{qtmajor}
%define libqtpositioning_d %mklibname qt%{qtmajor}positioning -d

Name:           qtpositioning6
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} Positioning component
Group:          Development/KDE and Qt
License:        LGPLv2 with exceptions or GPLv3 with exceptions and GFDL
URL:            https://www.qt.io
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz
#Branch Patchs

#Trunk Patchs

#Patch from Mageia

BuildRequires:  qtbase6-devel >= %{version}
BuildRequires:  cmake(Qt6Quick) >= %{version}
BuildRequires:  cmake(Qt6Qml) >= %{version}
BuildRequires:  cmake(Qt6SerialPort) >= %{version}
BuildRequires:  pkgconfig(geoclue-2.0)
BuildRequires:  pkgconfig(gconf-2.0)
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  pkgconfig(libssl)
BuildRequires:  ninja
BuildRequires:  qttools6

Provides:       qt%{qtmajor}-qtpositioning = %{version}-%{release}

%description
Qt%{qtmajor} Positioning API provides positioning information via QML and C++ interfaces.

%files
%{_qt6_plugindir}/position/
%{_qt6_archdatadir}/qml/QtPositioning
%{_qt6_archdatadir}/sbom/qtpositioning-%{qtversion}.spdx

#------------------------------------------------------------------------------

%if %{build_docs}
%package        doc
Summary:        QtPositioning%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools6
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools6-assistant
Recommends:     qttools6-assistant

%description doc
Documentation for APIs and tools in QtPositioning%{qtmajor} package for
use with Qt Assistant.

%files doc
%{_qt6_docdir}/qtpositioning.qch
%{_qt6_docdir}/qtpositioning/
%endif

#------------------------------------------------------------------------------

%package -n     %{libqtpositioning}
Summary:        Qt%{qtmajor} Positioning Library
Group:          System/Libraries
Requires:       %{name} >= %{version}

%description -n %{libqtpositioning}
Qt%{qtmajor} Positioning Component Library.

The Positioning module provides positioning information via QML
and C++ interfaces.

%files -n %{libqtpositioning}
%{_qt6_libdir}/libQt6Positioning.so.%{qtmajor}{,.*}
%{_qt6_libdir}/libQt6PositioningQuick.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtpositioning_d}
Summary:        Devel files needed to build apps based on QtPositioning
Group:          Development/KDE and Qt
Requires:       qtpositioning6 = %version
Requires:       %{libqtpositioning} = %version
Provides:       libqtpositioning6-devel = %version
Provides:       libqt6positioning-devel = %version
Provides:       qtpositioning6-devel = %version
Provides:       qt6positioning-devel = %version

Provides:       libqtpositioning6-private-devel = %version
Provides:       libqt6positioning-private-devel = %version
Provides:       qtpositioning6-private-devel = %version
Provides:       qt6positioning-private-devel = %version

%description -n %{libqtpositioning_d}
Devel files needed to build apps based on Qt Positioning.

%files -n %{libqtpositioning_d}
%{_qt6_headerdir}/QtPositioning/
%{_qt6_libdir}/libQt6Positioning.so
%{_qt6_libdir}/libQt6Positioning.prl
%{_qt6_libdir}/cmake/Qt6Positioning/
#
%{_qt6_headerdir}/QtPositioningQuick/
%{_qt6_libdir}/libQt6PositioningQuick.so
%{_qt6_libdir}/libQt6PositioningQuick.prl
%{_qt6_libdir}/cmake/Qt6PositioningQuick/
#
%{_qt6_libdir}/pkgconfig/*.pc
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_positioning*.pri
%{_qt6_libdir}/qt6/metatypes/qt6*_metatypes.json
%{_qt6_libdir}/qt6/modules/Positioning*.json
%if %{with examples}
%{_qt6_examplesdir}/positioning
%endif
#
%{_qt6_libdir}/cmake/Qt6/*.cmake
%{_qt6_libdir}/cmake/Qt6BuildInternals/StandaloneTests/QtPositioningTestsConfig.cmake
%dir %{_qt6_libdir}/cmake/Qt6Bundled_Clip2Tri
%{_qt6_libdir}/cmake/Qt6Bundled_Clip2Tri/Qt6Bundled_Clip2TriDependencies.cmake
%{_qt6_libdir}/cmake/Qt6Qml/QmlPlugins/*.cmake

#------------------------------------------------------------------------------

%prep
%setup -q -n qtpositioning-everywhere-src-%{qtversion}

%build
%cmake_qt6 %{!?with_examples:-DQT_BUILD_EXAMPLES:BOOL=OFF}
%cmake_build

%if %{build_docs}
%ninja_build -C build docs
%endif

%install
%cmake_install

%if %{build_docs}
%ninja_install -C build install_docs
%endif


%changelog
* Mon Jul 07 2025 umeabot <umeabot> 6.8.3-2.mga10
+ Revision: 2249998
- Mageia 10 Mass Rebuild

* Wed Mar 26 2025 daviddavid <daviddavid> 6.8.3-1.mga10
+ Revision: 2170113
- New version 6.8.3

* Fri Jan 03 2025 daviddavid <daviddavid> 6.8.1-2.mga10
+ Revision: 2135184
- own CMake configuration files dir

* Wed Dec 18 2024 daviddavid <daviddavid> 6.8.1-1.mga10
+ Revision: 2125914
- New version 6.8.1

* Sat Oct 05 2024 daviddavid <daviddavid> 6.7.3-1.mga10
+ Revision: 2103613
- New version 6.7.3

* Wed Sep 25 2024 daviddavid <daviddavid> 6.7.2-2.mga10
+ Revision: 2101223
- disable long time deprecated gypsy support
- enable docs building

* Wed Jul 31 2024 daviddavid <daviddavid> 6.7.2-1.mga10
+ Revision: 2083111
- New version 6.7.2

* Tue Jun 11 2024 daviddavid <daviddavid> 6.7.1-2.mga10
+ Revision: 2072543
- rebuild for 'Qt_$MAJOR_PRIVATE_API' settings

* Wed May 22 2024 daviddavid <daviddavid> 6.7.1-1.mga10
+ Revision: 2065883
- New version 6.7.1

* Thu Feb 15 2024 daviddavid <daviddavid> 6.6.2-1.mga10
+ Revision: 2041640
- New version 6.6.2

* Thu Oct 19 2023 daviddavid <daviddavid> 6.6.0-1.mga10
+ Revision: 1999040
- New version 6.6.0

* Sun Sep 10 2023 neoclust <neoclust> 6.5.2-1.mga10
+ Revision: 1985972
- New version 6.5.2

* Tue Dec 27 2022 daviddavid <daviddavid> 6.4.1-2.mga9
+ Revision: 1927061
- build examples

* Thu Dec 15 2022 neoclust <neoclust> 6.4.1-1.mga9
+ Revision: 1923049
- New version 6.4.1

* Fri Sep 30 2022 neoclust <neoclust> 6.4.0-1.mga9
+ Revision: 1893440
- New version 6.4.0

* Wed Sep 07 2022 guillomovitch <guillomovitch> 6.3.1-1.mga9
+ Revision: 1884690
- fix files list
+ neoclust <neoclust>
- New version 6.3.1

* Fri Jul 29 2022 wally <wally> 6.3.0-1.mga9
+ Revision: 1872865
- disable examples as they needs itself to build
- drop positioningquick lib
+ neoclust <neoclust>
- New version 6.3.0

* Sun Apr 10 2022 tmb <tmb> 6.2.3-2.mga9
+ Revision: 1848541
- Mageia 9 Mass Rebuild

* Thu Mar 17 2022 papoteur <papoteur> 6.2.3-1.mga9
+ Revision: 1797085
- imported package qtpositioning6

